# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need Test::More ≥ 0.96, so use a bundled one if we don't have it
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Email-Address
Version:	1.908
Release:	3.%{__distinit}%{__distvers}
Summary:	RFC 2822 Address Parsing and Creation
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Email-Address/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Email-Address-%{version}.tar.gz
Source1:	T-M-0.96.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Encode)
BuildRequires:	perl(Encode::MIME::Header)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Extra Tests
BuildRequires:	perl(Test::Pod) >= 1.41
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

BuildRequires:	perl(Scalar::Util)

%description
This class implements a complete RFC 2822 parser that locates email
addresses in strings and returns a list of "Email::Address" objects
found. Alternately you may construct objects manually. The goal of this
software is to be correct, and very very fast.

%prep
%setup -q -n Email-Address-%{version}
perl -pi -e 's|^#!/usr/local/bin/perl\b|#!/usr/bin/perl|' bench/ea-vs-ma.pl

# We need Test::More ≥ 0.96, so use a bundled one if we don't have it
%if %{old_test_more}
tar xfz %{SOURCE1}
find inc/Test -type f >> MANIFEST
%endif

%build
# Use our local Test::More if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
# Use our local Test::More if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README bench/
%{perl_vendorlib}/Email/
%{_mandir}/man3/Email::Address.3*

%changelog
* Sun Aug 21 2016 Paul Howarth <paul@city-fan.org> - 1.908-3
- BR: perl-generators where available
- Simplify find command using -delete

* Sun Sep 20 2015 Paul Howarth <paul@city-fan.org> - 1.908-1
- Update to 1.908
  - Default to 1 level of nested comments to avoid pathological behaviors

* Wed Feb  4 2015 Paul Howarth <paul@city-fan.org> - 1.907-1
- Update to 1.907
  - The test suite tests parses more directly, which eliminates a number of
    misleading (and possibly wrong) test cases
  - Escaped characters in a quoted string are now properly unescaped for the
    ->phrase method, which means things should round trip better from their
    decomposed form
- Classify buildreqs by usage
- Test suite has grown more complex, so use a bundled Test::More 0.96 instead
  of patching out the modern test code

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.905-2
- Use %%license where possible

* Wed Jun 18 2014 Paul Howarth <paul@city-fan.org> - 1.905-1
- Update to 1.905
  - Fix potential DoS issue in parsing of the phrase (CVE-2014-0477)
- Update patch for building with Test::More < 0.88

* Sun Apr 20 2014 Paul Howarth <paul@city-fan.org> - 1.903-1
- Update to 1.903
  - When formatting an address where phrase is empty but comment is not, do
    not include "" for the phrase; just omit it
  - When formatting an address where comment lacks enclosing parens, add them
- Update patch for building with Test::More < 0.88
- Drop support for old distributions prior to FC-5
  - Drop patch for building with ExtUtils::MakeMaker < 6.30
  - Drop %%defattr, redundant since rpm 4.4

* Wed Jan 29 2014 Paul Howarth <paul@city-fan.org> - 1.901-1
- Update to 1.901
  - Further avoidance of stringifying to undef
- Update patch for building with Test::More < 0.88

* Thu Aug  8 2013 Paul Howarth <paul@city-fan.org> - 1.900-1
- Update to 1.900
  - Avoid trying to stringify undef, and so avoid a warning

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 1.899-1
- Update to 1.899
  - Repackaged, pointed at new bug-tracker
  - Fallback overloads are enabled, so "cmp" will now compare with string
    overloads... which still might not be what you expect
  - Code has been futzed with to rely on some 5.6-isms, rather than trying to
    be 5.005 compatible
  - A warning has been added: calling ->parse in scalar context gets undefined
    behaviour
- Explicitly run the release tests
- Update buildreqs
- Update patch for building with Test::More < 0.88
- Add patch for building with ExtUtils::MakeMaker < 6.30

* Fri Feb  8 2013 Paul Howarth <paul@city-fan.org> - 1.898-1
- Update to 1.898
  - Remove dead link in POD

* Tue Dec 18 2012 Paul Howarth <paul@city-fan.org> - 1.897-1
- Update to 1.897
  - Skip mailboxes, rather than aborting the whole parse, when encountering
    non-ASCII characters
  - Improve the behaviour of escaping in phrases
- Update patch for building with Test::More < 0.88

* Wed Aug  1 2012 Paul Howarth <paul@city-fan.org> - 1.896-1
- Update to 1.896 (documentation improvements)

* Thu Jun 28 2012 Paul Howarth <paul@city-fan.org> - 1.895-2
- BR: perl(Encode), perl(Encode::MIME::Header), perl(ExtUtils::MakeMaker) and
  perl(Scalar::Util)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sun Jan 15 2012 Paul Howarth <paul@city-fan.org> - 1.895-1
- Update to 1.895 (allow non-ASCII, but only in phrase)
- Update patch for building with Test::More < 0.88

* Sat Jan 14 2012 Paul Howarth <paul@city-fan.org> - 1.894-1
- Update to 1.894 (note that the use of the regex vars is not a great idea)
- Update patch for building with Test::More < 0.88

* Tue Jan  3 2012 Paul Howarth <paul@city-fan.org> - 1.893-1
- Update to 1.893 (reject any non-ascii content in strings)
- Add patch to support building with Test::More < 0.88

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 1.892-2
- Rebuild for perl 5.14.1 in Rawhide
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Sep  6 2010 Paul Howarth <paul@city-fan.org> - 1.892-1
- Update to 1.892 (revert all behaviour to 1.889)
- Drop perl 5.10.0 requirement, no longer needed

* Mon Aug 23 2010 Paul Howarth <paul@city-fan.org> - 1.890-1
- Update to 1.890 (allow domainless addresses if requested)
- Now requires perl 5.10.0 or later due to use of branch reset pattern in regex

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.889-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 1.889-5
- Fix dist tag for RHEL-6 Beta

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> - 1.889-4
- Import from Fedora

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.889-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.889-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 12 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.889-1
- Upstream update

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.888-3
- Rebuild for perl 5.10 (again)

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.888-2
- Rebuild for new perl

* Sat Jun 23 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.888-1
- Update to 1.888

* Thu Apr  5 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.887-1
- Update to 1.887

* Sun Mar 18 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.886-1
- Update to 1.886

* Tue Dec 12 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.884-1
- Update to 1.884

* Sat Nov 25 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.883-1
- Update to 1.883

* Wed Nov 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.882-1
- Update to 1.882

* Sat Nov 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.880-1
- Update to 1.880

* Fri Oct 13 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.871-1
- Update to 1.871

* Sat Aug 12 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.870-1
- Update to 1.870

* Sat Jul 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.86-1
- Update to 1.86

* Tue Jul 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.85-1
- Update to 1.85

* Thu Sep 08 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.80-1
- First build
